From 03341e08fdef0aaf4f74f365a3709dc921089a46 Mon Sep 17 00:00:00 2001
From: Dave Cooper <open-source@genworks.com>
Date: Fri, 18 Oct 2013 13:43:33 -0400
Subject: [PATCH] protect against disallowed symbolic linking in
 test-multiple, allow for ALLEGRO_NOISY shell variable to
 show console in Allegro on Windows.

---
 test/run-tests.sh         | 17 ++++++++++++-----
 test/test-multiple.script | 14 +++++++++-----
 2 files changed, 21 insertions(+), 10 deletions(-)

diff --git a/test/run-tests.sh b/test/run-tests.sh
index 74f7fe0..1b614be 100755
--- a/test/run-tests.sh
+++ b/test/run-tests.sh
@@ -141,11 +141,18 @@ do_tests () {
   fi
 }
 
+#
+# not used currently but leave here for future reference.
+#
 case $(uname) in
     CYGWIN*) os=windows ;;
-    *) os=unix ;;
+    Darwin) os=macos ;;
+    Linux) os=linux ;;
+    *) os=unknown ;;
 esac
 
+
+
 # terminate on error
 set -e
 
@@ -160,23 +167,23 @@ case "$lisp" in
     command="${ALLEGRO:-alisp}"
     flags="-q"
     nodebug="-batch"
-    if [ "$os" = windows ] ; then bcmd="$command +c $flags" ; fi
+    if [ "$os" = windows ] && [ "$ALLEGRO_NOISY" = "" ] ; then bcmd="$command +c $flags" ; fi
     eval="-e" ;;
   allegro8)
     command="${ALLEGRO8:-alisp8}"
     flags="-q"
     nodebug="-batch"
-    if [ "$os" = windows ] ; then bcmd="$command +c $flags" ; fi
+    if [ "$os" = windows ] && [ "$ALLEGRO_NOISY" = "" ] ; then bcmd="$command +c $flags" ; fi
     eval="-e" ;;
   allegromodern)
     command="${ALLEGROMODERN:-mlisp}"
-    if [ "$os" = windows ] ; then bcmd="$command +c $flags" ; fi
+    if [ "$os" = windows ] && [ "$ALLEGRO_NOISY" = "" ] ; then bcmd="$command +c $flags" ; fi
     flags="-q"
     nodebug="-batch"
     eval="-e" ;;
   allegromodern8)
     command="${ALLEGROMODERN8:-mlisp8}"
-    if [ "$os" = windows ] ; then bcmd="$command +c $flags" ; fi
+    if [ "$os" = windows ] && [ "$ALLEGRO_NOISY" = "" ] ; then bcmd="$command +c $flags" ; fi
     flags="-q"
     nodebug="-batch"
     eval="-e" ;;
diff --git a/test/test-multiple.script b/test/test-multiple.script
index f71c184..f645671 100644
--- a/test/test-multiple.script
+++ b/test/test-multiple.script
@@ -9,11 +9,15 @@
 ;; Don't rely on ln -s on Windows
 (cond
   ((os-unix-p)
-   (run-program
-    (format nil "ln -sf ~A ~A"
-            (native-namestring asd)
-            (native-namestring asd2)))
-   (oos 'load-source-op 'test-multiple-too))
+   (multiple-value-bind (output error-output return-code)
+       (uiop:run-program  
+	(format nil "ln -sf ~A ~A"
+		(native-namestring asd)
+		(native-namestring asd2)) :ignore-error-status t)
+     (declare (ignore output error-output))
+     (oos 'load-source-op (if (zerop return-code) 
+			      'test-multiple-too
+			      'test-multiple))))
   (t
    (oos 'load-source-op 'test-multiple)))
 (assert (asymval :*file3* :test-package))
-- 
1.7.12.4 (Apple Git-37)

